@@ -262,7 +262,7 @@ public class CKanUtilsImpl implements CKanUtilsInterface{
 
 	@Override
 	public String getCatalogueUrl() {
-		return CKAN_CATALOGUE_URL;
+		return "https://" + CKAN_CATALOGUE_URL;
 	}
 
 	@Override
